/**
 * 需要分模块缓存的用本工具类 否则用  localStorageUtils.setLocal
 * @type {{setCountByID: Function, removeMTByID: Function, getTotalCount: Function, getCountByID: Function, getModuleList: Function}}
 */
var localModuleCacheHelper ={
    /**
     *设置本地购物车缓存
     * @param module 模块，比如购物车，我的收藏等
     * @param id id
     * @param count 数量
     * @param areaId 学校id 可以不传
     */
    setCountByID:function(module,id,count, areaId)
    {
        if(localStorageUtils.isSupportLocalStorge())
        {
            if(count >0) {
                localStorageUtils.setLocalStorage(module,id,['count'], [count],areaId);
            } else {
                localStorageUtils.removeLocalStorageByKey(module,id,areaId)
            }
            //this.updataCartBtnNum(type);
        }else{
            areaId = areaId ? areaId : "common";
            setCountByIDOnAndroid(module,id,count+"", areaId);
        }

    },
    /**
     * 移除本地缓存对象
     * @param module 模块，比如购物车，我的收藏等
     * @param id
     * @param areaId 学校id
     */
    removeMTByID:function(module,id,areaId)
    {
        if(localStorageUtils.isSupportLocalStorge())
        {
            localStorageUtils.removeLocalStorageByKey(module,id,areaId);
        }else{
            areaId = areaId ? areaId : "common";
            removeMTByIdOnAndroid(module,id,areaId);
        }

    },
    /**
     * 获取模块总数量
     * @param module 模块，比如购物车，我的收藏等
     * @param areaId 学校id 可以不传
     * @returns {number}
     */
    getTotalCount:function(module,areaId)
    {
        if(localStorageUtils.isSupportLocalStorge())
        {
            var tempCount = 0;
            var data = localStorageUtils.selectLocalStorage(module,"count",areaId);
            if(data && data.length)
            {
                for(var i = 0 ; i< data.length ; i++)
                {
                    tempCount += Number(data[i].count);
                }
            }
            return tempCount;
        }else{
            areaId = areaId ? areaId : "common";
            var count =  getModuleTotalCountOnAndroid(module,areaId);
            return count;
        }


    },
    /**
     * 根据id获取商品购物车数量
     * @param module 模块，比如购物车，我的收藏等
     * @param id
     * @param areaId 学校id  可以不传
     */
    getCountByID:function(module,id,areaId)
    {
        if(localStorageUtils.isSupportLocalStorge())
        {
            var data = localStorageUtils.getLocalStorage(module,id,areaId);
            if(data)
            {
                return data.count;
            }else{
                return 0;
            }
        }else{
            areaId = areaId ? areaId : "common";
            var data = getCountByIDOnAndroid(module,id,areaId);
            if(data)
            {
                return data;
            }else{
                return 0;
            }
        }
    },
    /**
     *
     * @param module  模块，比如购物车，我的收藏等
     * @param areaId 学校id
     * @returns {*}
     */
    getModuleList:function(module,areaId)
    {
        if(localStorageUtils.isSupportLocalStorge())
        {
            var data = localStorageUtils.selectLocalStorage(module,"count",areaId);
            if(data)
            {
                return data;
            }else{
                return [];
            }
        }else{
            areaId = areaId ? areaId : "common";
            var data =  getModuleList(module,areaId);
            if(data)
            {
                return data;
            }else{
                return [];
            }
        }
    }
}

